*****###########################Reads Industry Employment Table for Canada*###############
*#########################################################################################
*Does seasonal adjustment

clear all

*Set Directory
gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"
gl output2   = "...\output2"

adopath + "...\x12a" // Place seasonal adjustment files provided by Census Bureau and following instructions below. 
cd "${output2}/"


import excel "${rawdata}\Canada_ind.xlsx", sheet("canada_ind") cellrange(A9:FB93) firstrow clear

rename NorthAmericanIndustryClassifi naics
label variable naics naics
label variable Sex sex

foreach y of varlist _all{
   local x : variable label `y'
 rename `y' m`x'
}

rename msex sex
rename mnaics naics

keep if naics=="Agriculture 7" | naics=="Agriculture 8" | naics=="Agriculture 9" | naics=="Utilities" | naics=="Construction" | naics=="Manufacturing" | naics=="Wholesale and retail trade" | naics=="Transportation and warehousing" | naics=="Finance, insurance, real estate, rental and leasing" | naics=="Professional, scientific and technical services" | naics=="Business, building and other support services 11" | naics=="Business, building and other support services 12" | naics=="Business, building and other support services 13" | naics=="Educational services" | naics=="Health care and social assistance" | naics=="Health care and social assistance" | naics=="Accommodation and food services" | naics=="Other services (except public administration)" | naics=="Public administration" | naics=="Information, culture and recreation"

foreach y of varlist _all{
   destring `y', replace
}

reshape long m, i(naics sex) j(smdate) string 
gen month= substr(smdate,5,3)
gen year= substr(smdate,1,4)
destring year, replace
rename m emp

gen m=.
replace m=1 if month=="jan"
replace m=2 if month=="feb"
replace m=3 if month=="mar"
replace m=4 if month=="apr"
replace m=5 if month=="may"
replace m=6 if month=="jun"
replace m=7 if month=="jul"
replace m=8 if month=="aug"
replace m=9 if month=="sep"
replace m=10 if month=="oct"
replace m=11 if month=="nov"
replace m=12 if month=="dec"

gen agri=.
replace agri=emp if naics=="Agriculture 7" & sex=="Both sexes"
gen construction=.
replace construction=emp if naics=="Construction" & sex=="Both sexes"
gen manufacturing=.
replace manufacturing=emp if naics=="Manufacturing" & sex=="Both sexes"
gen trade=.
replace trade=emp if naics=="Wholesale and retail trade" & sex=="Both sexes"
gen transport=.
replace transport=emp if naics=="Transportation and warehousing" & sex=="Both sexes"
gen utu=.
replace utu=emp if naics=="Utilities" & sex=="Both sexes"
gen information=.
replace information=emp if naics=="Information, culture and recreation" & sex=="Both sexes"
gen finance=.
replace finance=emp if naics=="Finance, insurance, real estate, rental and leasing" & sex=="Both sexes"
gen prof=.
replace prof=emp if naics=="Professional, scientific and technical services" & sex=="Both sexes"
gen bus=.
replace bus=emp if naics=="Business, building and other support services 11" & sex=="Both sexes"
gen education=.
replace education=emp if naics=="Educational services" & sex=="Both sexes"
gen health=.
replace health=emp if naics=="Health care and social assistance" & sex=="Both sexes"
gen leisure=.
replace leisure=emp if naics=="Accommodation and food services" & sex=="Both sexes"
gen otherservices=.
replace otherservices=emp if naics=="Other services (except public administration)" & sex=="Both sexes"
gen government=.
replace government=emp if naics=="Public administration" & sex=="Both sexes"


gen agri_female=.
replace agri_female=emp if naics=="Agriculture 9" & sex=="Females"
gen construction_female=.
replace construction_female=emp if naics=="Construction" & sex=="Females"
gen manufacturing_female=.
replace manufacturing_female=emp if naics=="Manufacturing" & sex=="Females"
gen trade_female=.
replace trade_female=emp if naics=="Wholesale and retail trade" & sex=="Females"
gen transport_female=.
replace transport_female=emp if naics=="Transportation and warehousing" & sex=="Females"
gen utu_female=.
replace utu_female=emp if naics=="Utilities" & sex=="Females"
gen information_female=.
replace information_female=emp if naics=="Information, culture and recreation" & sex=="Females"
gen finance_female=.
replace finance_female=emp if naics=="Finance, insurance, real estate, rental and leasing" & sex=="Females"
gen prof_female=.
replace prof_female=emp if naics=="Professional, scientific and technical services" & sex=="Females"
gen bus_female=.
replace bus_female=emp if naics=="Business, building and other support services 13" & sex=="Females"
gen education_female=.
replace education_female=emp if naics=="Educational services" & sex=="Females"
gen health_female=.
replace health_female=emp if naics=="Health care and social assistance" & sex=="Females"
gen leisure_female=.
replace leisure_female=emp if naics=="Accommodation and food services" & sex=="Females"
gen otherservices_female=.
replace otherservices_female=emp if naics=="Other services (except public administration)" & sex=="Females"
gen government_female=.
replace government_female=emp if naics=="Public administration" & sex=="Females"



collapse agri construction manufacturing trade transport utu information finance prof bus education leisure otherservices government agri_female construction_female manufacturing_female trade_female transport_female utu_female information_female finance_female prof_female bus_female education_female health_female leisure_female otherservices_female government_female, by(year month m)

gen ttu=trade+transport+utu
gen ttu_female=trade_female+transport_female+utu_female
gen education_health=education+health
gen education_health_female=education_female+health_female
gen professional=prof+bus
gen professional_female=prof_female+bus_female

drop trade transport utu trade_female transport_female utu_female education education_female health health_female prof prof_female bus bus_female

sort year m

gen agri_male=agri-agri_female
gen construction_male=construction- construction_female
gen manufacturing_male= manufacturing-manufacturing_female
gen ttu_male=ttu-ttu_female 
gen information_male=information-information_female
gen finance_male=finance- finance_female
gen professional_male=professional-professional_female 
gen education_health_male=education_health-education_health_female
gen leisure_male=leisure-leisure_female
gen otherservices_male=otherservices-otherservices_female
gen government_male=government-government_female

*****Make it compatible with Europe code***********

rename construction construct
rename construction_female construct_female
rename construction_male construct_male
rename manufacturing manu
rename manufacturing_female manu_female
rename manufacturing_male manu_male
rename information info
rename information_male info_male
rename information_female info_female
rename finance fin_re
rename finance_female fin_re_female
rename finance_male fin_re_male
rename professional bus_ad
rename professional_female bus_ad_female
rename professional_male bus_ad_male
rename education_health ed_health
rename education_health_female ed_health_female
rename education_health_male ed_health_male
rename otherservices other_hh
rename otherservices_female other_hh_female
rename otherservices_male other_hh_male
rename government public
rename government_female public_female
rename government_male public_male

gen q=.
replace q=1 if m>=1 & m<=3
replace q=2 if m>=4 & m<=6
replace q=3 if m>=7 & m<=9
replace q=4 if m>=10 & m<=12

collapse agri_female agri_male construct_female manu_female ttu_female info_female fin_re_female bus_ad_female ed_health_female leisure_female other_hh_female public_female construct_male manu_male ttu_male info_male fin_re_male bus_ad_male ed_health_male leisure_male other_hh_male public_male, by(q year)

gen yq = yq(year, q)
format yq %tq
gen country="Canada"
encode country, gen(c)
tsset yq


************Seasonal adjustment*********


local mylist "agri_male agri_female construct_male construct_female info_male info_female public_male public_female other_hh_male other_hh_female manu_male manu_female ttu_male ttu_female bus_ad_male bus_ad_female ed_health_male ed_health_female leisure_male leisure_female fin_re_female fin_re_male" 
*########This code does seasonal adjustment using the program X-13ARIMA-SEATS by Census Bureau: https://www.census.gov/srd/www/x13as/
*We use instructions by Ernie Tedeschi: https://medium.com/@ernietedeschi/how-to-get-x-13arima-seats-working-in-stata-for-windows-9e2e03b7e9c6
foreach m of local mylist{
sax12 `m', satype(single) dtafile(`m')  
sax12im "`m'.out", ext(d11)
gen `m'_=`m'_d11 
}
keep  agri_male_ agri_female_ construct_male_ construct_female_ info_male_ info_female_ public_male_ public_female_ other_hh_male_ other_hh_female_ manu_male_ manu_female_ ttu_male_ ttu_female_ bus_ad_male_ bus_ad_female_ ed_health_male_ ed_health_female_ leisure_male_ leisure_female_ fin_re_female_ fin_re_male_  c country year q yq
local varlist "agri_male agri_female construct_male construct_female info_male info_female public_male public_female other_hh_male other_hh_female manu_male manu_female ttu_male ttu_female bus_ad_male bus_ad_female ed_health_male ed_health_female leisure_male leisure_female fin_re_female fin_re_male"
foreach v of local varlist{
rename `v'_ `v'
}

save "${procdata}\Canada_ind.dta",replace







