* Preliminaries
cls
clear all
set emptycells drop

* Directories *
gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"
cd "${output}/"

* Date *
use "${raw_data}/cps_00008.dta", clear // CPS microdata, #8 extends #6 back to include 98 and 99 data for  panel.

tab year
******************************************************************************** 
* Sample and Settings*
**********************

* Population Sample
keep if year>=1998 & year<=2020 //only have data going back to 2000 at the moment...need to update cps data file...
keep if age>=20 & age<=64
drop if occ2010>=9800 & occ2010<=9830 //drop military
drop if ind>=9670 & ind<=9870  //drop military

* Quarterly dummies 
gen Qt = .
replace Qt = 1 if month>=1  & month<=3
replace Qt = 2 if month>=4  & month<=6
replace Qt = 3 if month>=7  & month<=9
replace Qt = 4 if month>=10 & month<=12

* Employment rate
gen broad_emp = .
replace broad_emp = 0 if (empstat>=21 & empstat<=22) | (empstat>=32 & empstat<=36)
replace broad_emp = 1 if  empstat>=10 & empstat<=12

* Marital status
gen married = .
replace married = 1 if marst>=1 & marst<=2
replace married = 0 if marst>=3 & marst<=6

* usual hours 
* can replace last week hours from below; challenge then is to deal with seasonality in last week hours
gen raw_hours_usual = . //usual or last week (see below)
replace raw_hours_usual = uhrsworkt if uhrsworkt~=997  & uhrsworkt~=999  //usual hours worked metric, used as a robustness check\
replace raw_hours_usual = 0 if (uhrsworkt==997  | uhrsworkt==999)  & empstat==12 
replace raw_hours_usual = 0 if broad_emp==0 //unemployed and NILF get zero hours, for extensive margin
replace raw_hours_usual = . if raw_hours_usual>(24-8)*7 // drop those with impossibly high hours

* lask week hours
gen raw_hours_lwk = . // lwk hours show larger movements, but worse seasonality
replace raw_hours_lwk = ahrsworkt if ahrsworkt~=999  // hours worked last week, careful with missing values coded as 999
replace raw_hours_lwk = 0 if ahrsworkt==999 & empstat==12 // assign to those 0 hours, who are employed but did not work last week (empstat == 12) 
replace raw_hours_lwk = 0 if broad_emp==0 //unemployed and NILF get zero hours, for extensive margin
replace raw_hours_lwk = . if raw_hours_lwk>(24-8)*7 // drop those with impossibly high hours

* intensive hours only
gen intensive_hrs_lwk = .
replace intensive_hrs_lwk = raw_hours_lwk if raw_hours_lwk~=0

gen intensive_hrs_usual = .
replace intensive_hrs_usual = raw_hours_usual if raw_hours_usual~=0

// Make Sena Data for Export
preserve
collapse hours_usual = raw_hours_usual hours_lwk = raw_hours_lwk broad_emp intensive* [pw=wtfinl], by(year Qt)
tempfile agg
save "`agg'", replace
restore

// by gender
preserve
collapse hours_usual = raw_hours_usual hours_lwk = raw_hours_lwk broad_emp intensive* [pw=wtfinl], by(year Qt sex)
reshape wide hours* broad_emp intensive*, i(year Qt) j(sex)

rename hours_usual1 hours_usual_all_men
rename hours_usual2 hours_usual_all_women
rename hours_lwk1 hours_lwk_all_men
rename hours_lwk2 hours_lwk_all_women
rename broad_emp1 employment_all_men
rename broad_emp2 employment_all_women
rename intensive_hrs_lwk1 intensive_hrs_lwk_men
rename intensive_hrs_lwk2 intensive_hrs_lwk_women
rename intensive_hrs_usual1 intensive_hrs_usual_men
rename intensive_hrs_usual2 intensive_hrs_usual_women


tempfile gender
save "`gender'", replace

restore

// by gender and marital status
preserve
gen gms = 10*sex + married // gender and marital status group: 10 single men 11 married men 20 single women 21 married women
collapse hours_usual = raw_hours_usual hours_lwk = raw_hours_lwk broad_emp (sum) tot_hours_usual=raw_hours_usual tot_hours_lwk = raw_hours_lwk [pw=wtfinl], by(year Qt gms)
reshape wide hours_usual hours_lwk broad_emp tot_hours_usual tot_hours_lwk, i(year Qt) j(gms)

rename hours_usual10 hours_usual_single_men
rename hours_usual11 hours_usual_married_men
rename hours_usual20 hours_single_women
rename hours_usual21 hours_married_women

rename hours_lwk10 hours_lwk_single_men
rename hours_lwk11 hours_lwk_married_men
rename hours_lwk20 hours_lwk_single_women
rename hours_lwk21 hours_lwk_married_women

rename broad_emp10 employment_single_men
rename broad_emp11 employment_married_men
rename broad_emp20 employment_single_women
rename broad_emp21 employment_married_women

rename tot_hours_usual10 tot_hrs_usual_single_men
rename tot_hours_usual11 tot_hrs_usual_married_men
rename tot_hours_usual20 tot_hrs_usual_single_women
rename tot_hours_usual21 tot_hrs_usual_married_women

rename tot_hours_lwk10 tot_hrs_lwk_single_men
rename tot_hours_lwk11 tot_hrs_lwk_married_men
rename tot_hours_lwk20 tot_hrs_lwk_single_women
rename tot_hours_lwk21 tot_hrs_lwk_married_women


tempfile gen_mar
save "`gen_mar'", replace
restore



* Combine data and export
use "`agg'", clear
merge 1:1 year Qt using "`gender'"
drop _merge
merge 1:1 year Qt using "`gen_mar'"
drop _merge

sort year Qt
order year Qt hours_lwk* hours_usual* employment*
save "${procdata}/USA_data.dta", replace

