/* #############################################################################
Regression setup: Single mothers: cohabitation versus married
############################################################################# */


/*
1) focuses only on single mothers: 
- cohabitation
- marital status

*/

* Preliminaries
clear


* Directories *
cd "${local_workdir}"


* Log File
log using "${out_dir}/UK_DiD_Singlemothers.log", replace

* Load saved dataset
use "${local_workdir}/UK_cleaned_data.dta", clear



********************************************************************************
* Regressions: Single Motherhood = married OR cohabiting *
**********************************************************

* Compare mothers who are working and not working by child group 

// SPEC 4: Hours Last Week
preserve

* Mothers Sample
keep if sex==2 & (child_grp==1 | child_grp == 2) // mothers of children < 18 only

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

* Define broad cohabitation
gen broad_cohab = .
replace broad_cohab = 1 if cohab == 1 | married == 1
replace broad_cohab = 0 if cohab == 0 & married == 0

* Regressions

* Hours
reg hours_lwk Dt##ib1.broad_cohab#ib0.child_grp    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ [pweight=PWT18] , robust 							   
matrix motherhood = r(table) //store reg results

reg hours_lwk Dt##ib1.broad_cohab#ib0.child_grp Dt#i.work_type c.time_var_reg i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ  [pweight=PWT18] , robust 							   
matrix motherhood_occ = r(table) //store reg results


* Employment
reg broad_emp Dt##ib1.broad_cohab#ib0.child_grp    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ  [pweight=PWT18] , robust 							   
matrix motherhood_emp = r(table) //store reg results

reg broad_emp Dt##ib1.broad_cohab#ib0.child_grp Dt#i.work_type  i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ [pweight=PWT18] , robust 							   
matrix motherhood_emp_occ = r(table) //store reg results

restore



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 15") modify  // replace first time around 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
//hours
putexcel B1 =  "Hours Single Mom - Small Kids (bench)"
putexcel B2=motherhood[1,13]
putexcel B3=motherhood[2,13]
putexcel B4=motherhood[4,13]

putexcel C1 =  "Hours Single Mom - School Kids (bench)"
putexcel C2=motherhood[1,14]
putexcel C3=motherhood[2,14]
putexcel C4=motherhood[4,14]

putexcel D1 =  "Hours Single Mom - Small Kids (work type)"
putexcel D2=motherhood_occ[1,13]
putexcel D3=motherhood_occ[2,13]
putexcel D4=motherhood_occ[4,13]

putexcel E1 =  "Hours Single Mom - School Kids (work type)"
putexcel E2=motherhood_occ[1,14]
putexcel E3=motherhood_occ[2,14]
putexcel E4=motherhood_occ[4,14]


//employment
putexcel F1 =  "Employment Single Mom - Small Kids (bench)"
putexcel F2=motherhood_emp[1,13]
putexcel F3=motherhood_emp[2,13]
putexcel F4=motherhood_emp[4,13]

putexcel G1 =  "Employment Single Mom - School Kids (bench)"
putexcel G2=motherhood_emp[1,14]
putexcel G3=motherhood_emp[2,14]
putexcel G4=motherhood_emp[4,14]

putexcel H1 =  "Employment Single Mom - Small Kids (work type)"
putexcel H2=motherhood_emp_occ[1,13]
putexcel H3=motherhood_emp_occ[2,13]
putexcel H4=motherhood_emp_occ[4,13]

putexcel I1 =  "Employment Single Mom - School Kids (work type)"
putexcel I2=motherhood_emp_occ[1,14]
putexcel I3=motherhood_emp_occ[2,14]
putexcel I4=motherhood_emp_occ[4,14]



log close

