

* OBJECTIVE:  coeffs over time


* Preliminaries
cls
clear all
set maxvar 22000
set matsize 10000
set emptycells drop
capture log close

* Directories *
global raw_data ".../Raw Data" 
global out_dir ".../Output/USA" 

* Log file
log using "${out_dir}/Coefs over time/coeffs_over_time.log", replace


* Pre-made data set from regression analysis
use "${out_dir}/proc data/Master_MacroAnnual_Data.dta",replace

*use "${data}/proc data/Master_MacroAnnual_Data.dta",replace


********************************************************************************
********************************************************************************


* Benchmark Hours\Broad Emp  *
******************************

preserve

keep if Dt~=. | year>=2020
xtset  cpsidp time_var


* Employment

// occ controls
xtreg broad_emp ib720.time_var##ib1.sex      ib720.time_var##i.work_type       ,  fe 
est store occ_brdemp

// long time series
#delimit ;
coefplot (occ_brdemp ), name(ot_emp_occ_long,replace) vertical drop(_cons *t) keep(*time_var#*sex) yline(0) graphregion(color(white)) ytitle("Employment",margin(r=2)) 
coeflabels(,wrap(20) interaction(" x ") truncate(5) ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) ;
graph export "${out_dir}/Coefs over time/ot_emp_occ_long.png", replace ;
#delimit cr

// short time series
#delimit ;
coefplot (occ_brdemp), name(ot_brdemp_occ_final,replace) vertical xlabel(,format("%tmm"))
drop(_cons *t 70* 710* 711* 712* 713* 714* 715* 716* 717* 718* ) keep(*time_var#*sex) yline(0) graphregion(color(white)) ytitle("Employment",margin(r=2)) 
coeflabels(,wrap(20) interaction(" ") truncate(3) ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) ;
graph export "${out_dir}/Coefs over time/ot_brdemp_occ_final.png", replace ;
#delimit cr

* Hours

// occ controls
xtreg hours_lwk ib720.time_var##ib1.sex       ib720.time_var##i.work_type    ,  fe 
est store occ_hrs  

// long time series
#delimit ;
coefplot (occ_hrs ), name(ot_hrs_occ_long,replace) vertical drop(_cons *t) keep(*time_var#*sex) yline(0) graphregion(color(white)) ytitle("Hours",margin(r=2))
coeflabels(,wrap(20) interaction(" x ") truncate(5) ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) ;
graph export "${out_dir}/Coefs over time/ot_hrs_occ_long.png", replace ;
#delimit cr

//short time series
#delimit ;
coefplot (occ_hrs), name(ot_hrslwk_occ_final,replace) vertical 
drop(_cons *t 70* 710* 711* 712* 713* 714* 715* 716* 717* 718* ) keep(*time_var#*sex) yline(0) graphregion(color(white)) ytitle("Hours",margin(r=2)) 
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100);
graph export "${out_dir}/Coefs over time/ot_hrslwk_occ_final.png", replace ;
#delimit cr

restore


* Child Grps - interacted *
***************************


preserve

replace simple_child_grp = 1 if child_grp ==1 // simple_child_grp = 1 if kids age 0-17

keep if Dt~=. | year>=2020
xtset  cpsidp time_var

// Employment
xtreg broad_emp ib720.time_var#i.simple_child_grp##ib1.sex    ib720.time_var##i.work_type    ,  fe 
est store emp_occ_kidgrp

xtreg broad_emp ib720.time_var#ib1.simple_child_grp##ib1.sex   ib720.time_var##i.work_type   ,  fe 
est store emp_occ_kidgrp1


#delimit ; 
qui coefplot  (emp_occ_kidgrp),  title(" ")  name(ot_emp_occ_none_long,replace) vertical drop(_cons *1.simple_child_grp*) keep(*time_var#*sex) yline(0) graphregion(color(white)) ytitle("Employment",margin(r=2)) 
coeflabels(,wrap(20) interaction(" ") truncate(5) ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100)   yscale(range(-4(1)2)) ylabel(-4(1)2) ;
graph export "${out_dir}/Coefs over time/ot_emp_occ_none_long.png", replace ;
#delimit cr

#delimit ;
qui coefplot  (emp_occ_kidgrp1), title(" ") name(ot_emp_occ_kids_long,replace) vertical drop(_cons *0.simple_child_grp*) keep(*time_var#*sex) yline(0) graphregion(color(white))  /* ytitle("Employment",margin(r=2))*/ 
coeflabels(,wrap(20) interaction(" ") truncate(5) ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100)   yscale(range(-4(1)2)) ylabel(-4(1)2) ;
graph export "${out_dir}/Coefs over time/ot_emp_occ_kids_long.png", replace ;
#delimit cr


// Emp Short
#delimit ; 
qui coefplot  (emp_occ_kidgrp),  title("")  name(ot_emp_occ_none,replace) vertical drop(_cons *1.simple_child_grp* 70* *710* *711* *712* *713* *714* *715* *716* *717* *718* )  
keep(*time_var#*sex) yline(0) graphregion(color(white)) ytitle("Employment",margin(r=2))  yscale(range(-4(1)1.3)) ylabel(-4(1)1.3)
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) ;
graph export "${out_dir}/Coefs over time/ot_emp_occ_none.png", replace ;
#delimit cr

#delimit ;
qui coefplot  (emp_occ_kidgrp1), title("") name(ot_emp_occ_kids,replace) vertical drop(_cons *0.simple_child_grp* 70* *710* *711* *712* *713* *714* *715* *716* *717* *718* ) 
 keep(*time_var#*sex) yline(0) graphregion(color(white)) /* ytitle("Employment",margin(r=2))*/  yscale(range(-4(1)1.3)) ylabel(-4(1)1.3)
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) ;
graph export "${out_dir}/Coefs over time/ot_emp_occ_kids.png", replace ;
#delimit cr




// Hours Long
xtreg hours_lwk ib720.time_var#i.simple_child_grp##ib1.sex      ib720.time_var##i.work_type     ,  fe 
est store hrs_occ_kidgrp

xtreg hours_lwk ib720.time_var#ib1.simple_child_grp##ib1.sex      ib720.time_var##i.work_type   ,  fe 
est store hrs_occ_kidgrp1


#delimit ; 
qui coefplot  (hrs_occ_kidgrp),  title(" ")  name(ot_hrs_occ_none_long,replace) vertical drop(_cons *1.simple_child_grp*) keep(*time_var#*sex) yline(0) graphregion(color(white)) ytitle("Hours",margin(r=2)) 
coeflabels(,wrap(20) interaction(" ") truncate(5) ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) yscale(range(-18(5)7.5)) ylabel(-15(5)7.5);
graph export "${out_dir}/Coefs over time/ot_hrs_occ_none_long.png", replace ;
#delimit cr


#delimit ;
qui coefplot  (hrs_occ_kidgrp1), title(" ") name(ot_hrs_occ_kids_long,replace) vertical drop(_cons *0.simple_child_grp*) keep(*time_var#*sex) yline(0) graphregion(color(white)) /* ytitle("Hours",margin(r=2))*/ 
coeflabels(,wrap(20) interaction(" ") truncate(5) ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100)   yscale(range(-18(5)7.5)) ylabel(-15(5)7.5) ;
graph export "${out_dir}/Coefs over time/ot_hrs_occ_kids_long.png", replace ;
#delimit cr


// Hours Short
#delimit ; 
qui coefplot  (hrs_occ_kidgrp),  title("")  name(ot_hrs_occ_none,replace) vertical drop(_cons *1.simple_child_grp* 70* *710* *711* *712* *713* *714* *715* *716* *717* *718* )  
keep(*time_var#*sex) yline(0) graphregion(color(white))   ytitle("Hours",margin(r=2)) yscale(range(-18(5)6)) ylabel(-15(5)6)
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) ;
graph export "${out_dir}/Coefs over time/ot_hrs_occ_none.png", replace ;
#delimit cr


#delimit ;
qui coefplot  (hrs_occ_kidgrp1), title("") name(ot_hrs_occ_kids,replace) vertical drop(_cons *0.simple_child_grp* 70* *710* *711* *712* *713* *714* *715* *716* *717* *718* ) 
 keep(*time_var#*sex) yline(0) graphregion(color(white))  /* ytitle("Hours",margin(r=2))*/ yscale(range(-18(5)6)) ylabel(-15(5)6)
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) ;
graph export "${out_dir}/Coefs over time/ot_hrs_occ_kids.png", replace ;
#delimit cr



restore










*************************************************************************************************************************************
*************************************************************************************************************************************


** All child groups as in main tables
preserve

keep if Dt~=. | year>=2020
xtset  cpsidp time_var

// Employment
xtreg broad_emp ib720.time_var#ib0.child_grp##ib1.sex    ib720.time_var##i.work_type       ,  fe 
est store emp_occ_kidgrp_det0

xtreg broad_emp ib720.time_var#ib1.child_grp##ib1.sex   ib720.time_var##i.work_type        ,  fe 
est store emp_occ_kidgrp_det1

xtreg broad_emp ib720.time_var#ib2.child_grp##ib1.sex   ib720.time_var##i.work_type        ,  fe 
est store emp_occ_kidgrp_det2  

// Hours Long
xtreg hours_lwk ib720.time_var#ib0.child_grp##ib1.sex      ib720.time_var##i.work_type     ,  fe 
est store hrs_occ_kidgrp_det0

xtreg hours_lwk ib720.time_var#ib1.child_grp##ib1.sex      ib720.time_var##i.work_type     ,  fe 
est store hrs_occ_kidgrp_det1

xtreg hours_lwk ib720.time_var#ib2.child_grp##ib1.sex      ib720.time_var##i.work_type     ,  fe 
est store hrs_occ_kidgrp_det2


// Emp Short
#delimit ; 
qui coefplot  (emp_occ_kidgrp_det0),  title("")  name(ot_emp_occ_none_det,replace) vertical drop(_cons *1.child_grp* *2.child_grp* 70* *710* *711* *712* *713* *714* *715* *716* *717* *718* )  
keep(*time_var#*sex) yline(0) graphregion(color(white)) ytitle("Employment",margin(r=2))  yscale(range(-4(1)2)) ylabel(-4(1)2)
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) subtitle("employment - no kids") ;
graph export "${out_dir}/Coefs over time/ot_emp_occ_none_det.png", replace ;
#delimit cr

#delimit ;
qui coefplot  (emp_occ_kidgrp_det1), title("") name(ot_emp_occ_kidsYoung_det,replace) vertical drop(_cons *0.child_grp* *2.child_grp* 70* *710* *711* *712* *713* *714* *715* *716* *717* *718* ) 
 keep(*time_var#*sex) yline(0) graphregion(color(white)) /* ytitle("Employment",margin(r=2))*/  yscale(range(-4(1)2)) ylabel(-4(1)2)
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) subtitle("employment - kids <5");
graph export "${out_dir}/Coefs over time/ot_emp_occ_kidsYoung_det.png", replace ;
#delimit cr

#delimit ;
qui coefplot  (emp_occ_kidgrp_det2), title("") name(ot_emp_occ_kidsOld_det,replace) vertical drop(_cons *0.child_grp* *1.child_grp* 70* *710* *711* *712* *713* *714* *715* *716* *717* *718* ) 
 keep(*time_var#*sex) yline(0) graphregion(color(white)) /* ytitle("Employment",margin(r=2))*/  yscale(range(-4(1)2)) ylabel(-4(1)2)
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) subtitle("employment - kids 5-17") ;
graph export "${out_dir}/Coefs over time/ot_emp_occ_kidsOld_det.png", replace ;
#delimit cr



// Hours Short
#delimit ; 
qui coefplot  (hrs_occ_kidgrp_det0),  title("")  name(ot_hrs_occ_none_det,replace) vertical drop(_cons *1.child_grp* *2.child_grp* 70* *710* *711* *712* *713* *714* *715* *716* *717* *718* )  
keep(*time_var#*sex) yline(0) graphregion(color(white))   ytitle("Hours",margin(r=2)) yscale(range(-20(5)12)) ylabel(-20(5)12)
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) subtitle("hours - no kids") ;
graph export "${out_dir}/Coefs over time/ot_hrs_occ_none_det.png", replace ;
#delimit cr

#delimit ;
qui coefplot  (hrs_occ_kidgrp_det1), title("") name(ot_hrs_occ_kidsYoung_det,replace) vertical drop(_cons *0.child_grp* *2.child_grp* 70* *710* *711* *712* *713* *714* *715* *716* *717* *718* ) 
 keep(*time_var#*sex) yline(0) graphregion(color(white))  /* ytitle("Hours",margin(r=2))*/ yscale(range(-20(5)12)) ylabel(-20(5)12)
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) subtitle("hours - kids <5");
graph export "${out_dir}/Coefs over time/ot_hrs_occ_kidsYoung_det.png", replace ;
#delimit cr

#delimit ;
qui coefplot  (hrs_occ_kidgrp_det2), title("") name(ot_hrs_occ_kidsOld_det,replace) vertical drop(_cons *0.child_grp* *1.child_grp* 70* *710* *711* *712* *713* *714* *715* *716* *717* *718* ) 
 keep(*time_var#*sex) yline(0) graphregion(color(white))  /* ytitle("Hours",margin(r=2))*/ yscale(range(-20(5)12)) ylabel(-20(5)12)
coeflabels(,wrap(20) interaction(" ") truncate(3)  ) baselevel legend(r(1)) levels(95) ciopts(recast(rcap)) legend(off) rescale(100) subtitle("hours - kids 5-17");
graph export "${out_dir}/Coefs over time/ot_hrs_occ_kidsOld_det.png", replace ;
#delimit cr

restore





********************************************************************************
********************************************************************************
log close
